@@ -765,6 +765,8 @@ typedef struct DenemoAudio {
   gint channels;
   gint leadin;/**< number of frames to skip at start, silence to be emitted before play if negative */
   gdouble volume;
+  gint nframes;/**< number of frames in the audio */
+  GList *onsets;  /**< Candidate note onsets in sndfile */
   gpointer sndfile; /**< sndfile handle */
 } DenemoAudio;
 
@@ -815,6 +817,8 @@ typedef struct DenemoScore
   gint staffspace;
 
   DenemoAudio *audio;/**< Audio attached to movement */ 
+  gint marked_onset_position;/**< horizontal position in display of note onset in audio marked by user */ 
+  GList *marked_onset;/**< Note onset in audio selected by user */ 
   GList *sources; /**< List of source pixbufs, one for each measure score-view*/
   gdouble start_time; /**< time in seconds to start playing at */
   gdouble end_time; /**< time to end playing at */
