@@ -15,8 +15,7 @@
  *
  */
 void
-draw_lyric (cairo_t *cr,
-	    gint xx, gint y, gchar *text)
+draw_lyric (cairo_t * cr, gint xx, gint y, gchar * text)
 {
-  drawnormaltext_cr( cr, text, xx, y + STAFF_HEIGHT + 12);
+  drawnormaltext_cr (cr, text, xx, y + STAFF_HEIGHT + 12);
 }
