@@ -529,7 +529,7 @@ filesel_save (DenemoGUI * gui, const gchar * file_name, gint format_id, DenemoSa
 static void
 init_local_path (void)
 {
-  local_template_path = g_build_filename (locatedotdenemo (), "templates", NULL);
+  local_template_path = g_build_filename (get_user_data_dir (), "templates", NULL);
   gboolean err = g_mkdir_with_parents (local_template_path, 0770);
   if (err)
     {
@@ -569,7 +569,7 @@ template_open (DenemoGUI * gui, TemplateType local, gchar * filename)
     {
       if (system_example_path == NULL)
         {
-          system_example_path = g_build_filename (get_data_dir (), "examples", NULL);
+          system_example_path = g_build_filename (get_system_data_dir (), "examples", NULL);
           GDir *denemo_path = g_dir_open (system_example_path, 0, NULL);
           if (denemo_path == NULL)
             {
@@ -583,7 +583,7 @@ template_open (DenemoGUI * gui, TemplateType local, gchar * filename)
     {
       if (system_template_path == NULL)
         {
-          system_template_path = g_build_filename (get_data_dir (), "templates", NULL);
+          system_template_path = g_build_filename (get_system_data_dir (), "templates", NULL);
           GDir *denemo_path = g_dir_open (system_template_path, 0, NULL);
           if (denemo_path == NULL)
             {
@@ -1112,7 +1112,7 @@ gint
 open_user_default_template (ImportType type)
 {
   gint ret = -1;
-  gchar *filename = g_build_filename (locatedotdenemo (), "templates", "default.denemo", NULL);
+  gchar *filename = g_build_filename (get_user_data_dir (), "templates", "default.denemo", NULL);
   if (g_file_test (filename, G_FILE_TEST_EXISTS))
     {
       ret = open_for_real (filename, Denemo.gui, TRUE, type);
@@ -1171,7 +1171,7 @@ selection_received (G_GNUC_UNUSED GtkClipboard * clipboard, const gchar * text,
       warningdialog (_("No selection text available"));
       return;
     }
-  gchar *filename = g_build_filename (locatedotdenemo (), "denemopaste.ly", NULL);
+  gchar *filename = g_build_filename (get_user_data_dir (), "denemopaste.ly", NULL);
   FILE *fp = fopen (filename, "w");
   if (fp)
     {
