@@ -162,4 +162,7 @@ void dnm_clean_event (GdkEventKey * event);
 gint add_twokeybinding_to_idx (keymap * the_keymap, gint first_keyval, GdkModifierType first_state, gint keyval, GdkModifierType state, guint command_idx, ListPosition pos);
 
 void command_row_init(command_row *command);
+gboolean keymap_get_command_row (keymap * the_keymap, command_row * row, guint command_idx);
+gboolean is_action_id_builtin(gint id);
+gboolean is_action_name_builtin(gchar* command_name);
 #endif
