@@ -173,6 +173,7 @@ removemeasures (DenemoScore * si, guint pos, guint nummeasures, gboolean all)
     {
       for (i = 0; i < nummeasures; i++)
         {
+          totalmeasures = 0;
           for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
             {
               if (curstaff == si->currentstaff || all)
@@ -291,7 +292,16 @@ settickvalsinmeasure (objnode * theobjs)
                 {
                   set_tuplefied_numticks (theobj, numerator, denominator);
                   basic_ticks_in_tuplet_group += theobj->basic_durinticks;
-                }               //FIXME set up endgrace as needed for grace notes inside tuplets
+                }  else
+                {
+                    if(is_end_grace (curobjnode))
+                      ((chord *) theobj->object)->is_grace |= ENDGRACE;
+                    else
+                      ((chord *) theobj->object)->is_grace &= (~ENDGRACE);    //and re-instate if needed
+                    theobj->durinticks = 0;
+                }
+
+                
             }
           else
             {
@@ -300,8 +310,11 @@ settickvalsinmeasure (objnode * theobjs)
 
               if (((chord *) theobj->object)->is_grace)
                 {
-                  ((chord *) theobj->object)->is_grace |= is_end_grace (curobjnode);    //and re-instate if needed
-                  theobj->durinticks = 0;
+                    if(is_end_grace (curobjnode))
+                      ((chord *) theobj->object)->is_grace |= ENDGRACE;
+                    else
+                      ((chord *) theobj->object)->is_grace &= (~ENDGRACE);    //and re-instate if needed
+                    theobj->durinticks = 0;
                 }
               else
                 theobj->durinticks = theobj->basic_durinticks;
