@@ -41,7 +41,8 @@ add_font_directory (gchar * fontpath)
 #ifdef G_OS_WIN32
   AddFontResource (fontpath);
 #endif
-  FcConfigAppFontAddDir (NULL, (FcChar8*) fontpath);
+  if(FcConfigAppFontAddDir (NULL, (FcChar8*) fontpath) == FcFalse)
+    g_warning("Failed to add font dir %s.", fontpath);
 }
 
 void
@@ -50,7 +51,8 @@ add_font_file (gchar * fontname)
 #ifdef G_OS_WIN32
   AddFontResource (fontname);
 #endif
-  FcConfigAppFontAddFile (NULL, (FcChar8*) fontname);
+  if(FcConfigAppFontAddFile (NULL, (FcChar8*) fontname) == FcFalse)
+    g_warning("Failed to add font file %s.", fontname);
 }
 
 #ifdef G_OS_WIN32
@@ -187,22 +189,16 @@ progress_timeout (ProgressData * pdata)
 
 static ProgressData progress_data;
 
-static gboolean
-call_stop_lilypond (GtkWidget * w, GdkEvent * event, ProgressData * pdata)
-{
-  progressing = FALSE;
-  stop_lilypond ();
-  return TRUE;
-}
+
 
 /**
  * Displays progress bar
- * window should close upon completion
- * @param msg message to display
- * @return none
+ * optionally pass a callback to be run on destruction
+ * @param msg message to display, callback (can be NULL)
+ * @return the GtkWindow of the progress bar
  */
-void
-progressbar (gchar * msg)
+GtkWindow *
+progressbar (gchar * msg, gpointer callback)
 {
 
   GtkWidget *vbox;
@@ -217,7 +213,7 @@ progressbar (gchar * msg)
       /* Replace GTK_WINDOW_TOPLEVEL with GTK_WINDOW_POPUP
        * to have it without window decoration. 
        */
-      if (Denemo.prefs.progressbardecorations)
+      if (callback && Denemo.prefs.progressbardecorations)
         pdata->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
       else
         pdata->window = gtk_window_new (GTK_WINDOW_POPUP);
@@ -241,10 +237,11 @@ progressbar (gchar * msg)
   gtk_window_set_keep_above (GTK_WINDOW (pdata->window), TRUE);
   gtk_widget_show (pdata->window);
   /* If widget is destroyed stop the printing */
-  /* TODO This should be fed by a function argurment
-     so that that it can stop other things besides
-     lilypond */
-  g_signal_connect (G_OBJECT (pdata->window), "delete-event", G_CALLBACK (call_stop_lilypond), pdata);
+  if(callback)
+	g_signal_connect (G_OBJECT (pdata->window), "delete-event", G_CALLBACK (callback /*call_stop_lilypond*/), (gpointer)&progressing);
+  else
+	g_signal_connect (G_OBJECT (pdata->window), "delete-event", G_CALLBACK (progressbar_stop), NULL);
+  return pdata->window;
 }
 
 void
@@ -253,6 +250,27 @@ progressbar_stop ()
   progressing = FALSE;
 }
 
+
+void
+busy_cursor (GtkWidget *area)
+{
+  static GdkCursor *busycursor = NULL;
+  if(!busycursor)
+    busycursor = gdk_cursor_new (GDK_WATCH);
+  if (gtk_widget_get_window (Denemo.printarea))
+    gdk_window_set_cursor (gtk_widget_get_window (area), busycursor);
+}
+void
+normal_cursor (GtkWidget *area)
+{
+  static GdkCursor *arrowcursor = NULL;
+  if(!arrowcursor)
+    arrowcursor = gdk_cursor_new (GDK_RIGHT_PTR);
+  if (gtk_widget_get_window (area))
+    gdk_window_set_cursor (gtk_widget_get_window (area), arrowcursor);
+}
+
+
 /**
  *  Draws the given bitmap mask on to the pixmap using the given 
  *  grahpics context.
@@ -947,7 +965,7 @@ initdir ()
 extern gchar *gbr_find_pkg_data_dir (const gchar * default_pkg_data_dir, const gchar * pkg_name);
 
 const gchar *
-get_data_dir ()
+get_system_data_dir ()
 {
   static gchar *datadir = NULL;
   if (datadir == NULL)
@@ -1022,7 +1040,7 @@ get_prefix_dir (void)
 }
 
 const gchar *
-get_bin_dir (void)
+get_system_bin_dir (void)
 {
   static gchar *bindir = NULL;
   if (bindir == NULL)
@@ -1066,8 +1084,9 @@ get_bin_dir (void)
   return bindir;
 }
 
+/** UNUSED
 const gchar *
-get_conf_dir ()
+get_system_conf_dir ()
 {
   static gchar *confdir = NULL;
   if (confdir == NULL)
@@ -1076,7 +1095,7 @@ get_conf_dir ()
       gchar *rootdir = g_win32_get_package_installation_directory (NULL, NULL);
       confdir = g_build_filename (rootdir, "etc", "denemo", NULL);
       g_free (rootdir);
-#else /* not G_OS_WIN32 */
+#else // not G_OS_WIN32 
 #ifdef _MACH_O_
 
       {
@@ -1100,13 +1119,14 @@ get_conf_dir ()
 #endif //ENABLE_BINRELOC
 
 #endif //_MACH_O_
-#endif /* not G_OS_WIN32 */
+#endif // not G_OS_WIN32
     }
   return confdir;
 }
+*/
 
 const gchar *
-get_locale_dir ()
+get_system_locale_dir ()
 {
   static gchar *localedir = NULL;
   if (localedir == NULL)
@@ -1150,6 +1170,21 @@ get_locale_dir ()
   return localedir;
 }
 
+const gchar*
+get_system_font_dir(){
+  static gchar* fontdir = NULL;
+  if(fontdir == NULL)
+  {
+#ifdef G_OS_WIN32
+    gchar *prefix = g_win32_get_package_installation_directory (NULL, NULL);
+#else
+    gchar *prefix = g_build_filename (get_prefix_dir (), NULL);
+#endif
+    fontdir = g_build_filename (prefix, "share", "fonts", "truetype", "denemo", NULL);
+  }
+  return fontdir;
+}
+
 void
 kill_process (GPid pid)
 {
@@ -1461,7 +1496,7 @@ append_directives_information (GString * selection, GList * directives)
 			if(directive->postfix)
 				 g_string_append_printf (selection, _("LilyPond inserted in postfix to this object is \"%s\"\n"), directive->postfix->str);
       if(tooltip)
-        g_string_append_printf (selection, _("The help for the command that created this directive is:\n\"%s\""), tooltip);
+        g_string_append_printf (selection, _("The help for the command that created this directive is:\n\"%s\"\n"), tooltip);
     }
   while (directives->next && (directives = directives->next));
 }
@@ -1517,9 +1552,9 @@ display_current_object (void)
                 if (thechord->is_tied)
                   selection = g_string_append (selection, _("This is tied to the following note or chord.\n" "The following note or chord should have the same pitch"));
                 if (thechord->is_grace && !(thechord->is_grace & GRACED_NOTE))
-                  selection = g_string_append (selection, _("This is an acciacatura note\n"));
+                  selection = g_string_append (selection, _("This is an acciaccatura note\n"));
                 if (thechord->is_grace & GRACED_NOTE)
-                  selection = g_string_append (selection, _("This is an appogiatura note\n"));
+                  selection = g_string_append (selection, _("This is an appoggiatura note\n"));
                 if (curObj->isinvisible)
                   selection = g_string_append (selection, _("This note denotes a rhythm - use a MIDI keyboard to add pitches by playing.\n"));
 
@@ -2353,3 +2388,94 @@ find_path_for_file(gchar* filename, gchar* dirs[])
   }
   return NULL;
 }
+
+const gchar*
+get_local_dir(DenemoDirectory dir)
+{
+  switch(dir)
+  {
+    case COMMANDS:   return COMMANDS_DIR;
+    case UI:         return UI_DIR;
+    case SOUNDFONTS: return SOUNDFONTS_DIR;
+    case PIXMAPS:    return PIXMAPS_DIR;
+    case FONTS:      return FONTS_DIR;
+    case LOCALE:     return LOCALE_DIR;
+    default:         return NULL;
+  }
+}
+
+gchar*
+get_system_dir(DenemoDirectory dir)
+{
+  switch(dir)
+  {
+    case COMMANDS:
+    case UI:
+    case SOUNDFONTS:
+    case FONTS:
+      return g_build_filename(get_system_data_dir (), get_local_dir(dir), NULL);
+#ifndef G_OS_WIN32
+    case PIXMAPS:
+      return g_build_filename(get_system_data_dir (), "..", PIXMAPS_DIR, NULL);
+      break;
+#endif
+    case LOCALE:
+      return g_strdup(get_system_locale_dir ());
+      break;
+    case BIN:
+      return g_strdup(get_system_bin_dir ());
+      break;
+    default:
+      return NULL;
+  }
+}
+
+const gchar*
+get_executable_dir ()
+{
+  static const gchar* dir = NULL;
+  if(dir == NULL)
+  {
+    char path[1024];
+
+#ifdef G_OS_WIN32
+    GetModuleFileNameW(NULL, path, MAX_PATH);
+
+#elif defined _MACH_O_
+    char path[1024];
+    guint size = sizeof (path);
+    _NSGetExecutablePath (path, &size);
+
+#else
+   readlink("/proc/self/exe", path, sizeof(path));
+
+#endif
+    dir = g_path_get_dirname(path);
+  }
+  return dir;
+}
+/**
+ * find:
+ * @dir: The denemo directory where to search
+ * @filename: The file to search
+ *
+ * Finds a file by searching:
+ *  - in the local directory
+ *  - in the executable parent directory
+ *  - in the user directory
+ *  - in the system directory
+ **/
+gchar*
+find(DenemoDirectory dir, gchar* filename)
+{
+  gchar* current = g_get_current_dir ();
+  gchar* dirs[] = {
+    //g_build_filename(current, get_local_dir (dir), NULL),
+    g_build_filename(get_executable_dir (), "..", get_local_dir (dir), NULL),
+    g_build_filename(get_user_data_dir(), get_local_dir (dir), NULL),
+    g_build_filename(get_system_dir(dir), NULL),
+    NULL
+  };
+  g_free(current);
+  return find_path_for_file (filename, dirs);
+}
