@@ -101,18 +101,24 @@ void warningdialog (gchar * msg);
 
 GtkWidget *infodialog (gchar * msg);
 
-void progressbar (gchar * msg);
+GtkWindow *progressbar (gchar * msg, gpointer callback);
 void progressbar_stop (void);
-
+void busy_cursor (GtkWidget *area);
+void normal_cursor (GtkWidget *area);
 void headerfields (GtkWidget * dialog, GtkListStore * list_store, GtkTreeIter * iter, DenemoScore * si, gboolean isdialog);
 /* default isdialog shall be TRUE */
 
 
 void initdir (void);
-const gchar *get_data_dir (void);
-const gchar *get_conf_dir (void);
-const gchar *get_locale_dir (void);
-const gchar *get_bin_dir (void);
+const gchar *get_system_data_dir (void);
+/* UNUSED
+const gchar *get_system_conf_dir (void);
+*/
+const gchar *get_system_locale_dir (void);
+const gchar *get_system_bin_dir (void);
+const gchar *get_system_font_dir();
+const gchar *get_executable_dir();
+
 void kill_process (GPid pid);
 
 gchar *music_font (gchar * str);
@@ -285,4 +291,5 @@ void write_input_status();
 enum clefs cleftypefromname (gchar * str);
 gchar* find_dir_for_file(gchar* filename, gchar* dirs[]);
 gchar* find_path_for_file(gchar* filename, gchar* dirs[]);
+gchar* find(DenemoDirectory dir, gchar* filename);
 #endif /* UTILS_H */
